@@ -5,10 +5,10 @@ from rayvision_api.utils import json_load
 from rayvision_api import RayvisionAPI
 
 render_para = {
-    "domain": "task.renderbus.com",  # 用戶不需要修改
+    "domain": "task.renderbus.com",
     "platform": "2",
-    "access_id": "xxxx",  # 用户自行修改(必填)
-    "access_key": "xxxx",  # 用户自行修改(必填)
+    "access_id": "xxxxxxx",
+    "access_key": "xxxxxxx",
 }
 
 api = RayvisionAPI(access_id=render_para['access_id'],
@@ -20,7 +20,7 @@ api = RayvisionAPI(access_id=render_para['access_id'],
 # task_id = api.task.task_id
 
 # print("======= 根据task_id提交任务 =============")
-# api.submit(task_id=24118143)
+# api.submit(task_id=1479581)
 
 # print("======= 根据task_info提交任务 =============")
 # task_json_content = json_load(json_path=r"C:\workspace\1590129962\task.json")
@@ -28,7 +28,7 @@ api = RayvisionAPI(access_id=render_para['access_id'],
 
 # print("======= 根据task_info提交任务 =============")
 # json_content = json.dumps(json_load(json_path=r"C:\workspace\1590129962\task.json"))
-# api.transmit.upload_json_content(task_id=24118143, content=json_content, file_name="task.json")
+# api.transmit.upload_json_content(task_id=1479581, content=json_content, file_name="task.json")
 
 # print("======= 获取平台列表 =============")
 # platform = api.query.platforms()
@@ -48,43 +48,43 @@ api = RayvisionAPI(access_id=render_para['access_id'],
 #
 # print("======= 获取用户传输BID =============")
 # user_transfer_bid = api.user.get_transfer_bid()
-# print(user_transfer_bid)
+# print(json.dumps(user_transfer_bid, indent=4))
 #
 # print("======= 创建任务号 =============")
-# create_task_id = api.task.create_task(count=1, task_user_level=50, labels=["label_test1"])
+# create_task_id = api.task.create_task(count=1, clone_original_id=1479305)
 # print(create_task_id)
 
 # print("======= 提交任务 =============")
-# task_id = create_task_id["taskIdList"][0]
-# submit_task = api.task.submit_task(task_id=task_id)
+# # task_id = create_task_id["taskIdList"][0]
+# submit_task = api.task.submit_task(task_id=1479421)
 # print(submit_task)
 
 # print("======= 获取分析错误码 =============")
-# error_detail = api.query.error_detail(code="601")
-# print(error_detail)
+# error_detail = api.query.error_detail(code="675474")
+# print(json.dumps(error_detail, indent=4, ensure_ascii=False))
 #
 # print("======= 获取任务列表 =============")
-# task_list = api.query.get_task_list(page_num=1, page_size=1)
+# task_list = api.query.get_task_list(status_list=[10])
 # print(task_list)
 #
 # print("======= 停止任务 =============")
-# stop_task = api.task.stop_task(task_param_list=[23750805])
+# stop_task = api.task.stop_task(task_param_list=[1479305])
 # print(stop_task)
 
 # print("======= 开始任务 =============")
-# start_task = api.task.start_task(task_param_list=[23750805])
+# start_task = api.task.start_task(task_param_list=[1479305])
 # print(start_task)
 
 # print("======= 放弃任务 =============")
-# abort_task = api.task.abort_task(task_param_list=[23750805])
+# abort_task = api.task.abort_task(task_param_list=[1479305])
 # print(abort_task)
 
 # print("======= 删除任务 =============")
-# delete_task = api.task.delete_task(task_param_list=[23750805])
+# delete_task = api.task.delete_task(task_param_list=[1479305])
 # print(delete_task)
 
 # print("======= 获取任务渲染帧详情 =============")
-# task_frame = api.query.task_frames(task_id=23750805, page_num=1, page_size=1)
+# task_frame = api.query.task_frames(task_id=1479311, page_num=1, page_size=1)
 # print(task_frame)
 
 # print("======= 获取任务总渲染帧概况 =============")
@@ -92,23 +92,23 @@ api = RayvisionAPI(access_id=render_para['access_id'],
 # print(all_frame_status)
 
 # print("======= 重提失败帧 =============")
-# # restart_failed_frames = api.query.restart_failed_frames(task_param_list=[13788981])
-# # print(restart_failed_frames)
+# restart_failed_frames = api.query.restart_failed_frames(task_param_list=[1479305])
+# print(restart_failed_frames)
 
 # print("======= 重提任务指定帧 =============")
-# restart_frame = api.query.restart_frame(task_id=14362099, select_all=1)
+# restart_frame = api.query.restart_frame(task_id=1479307, select_all=1, status=[3])
 # print(restart_frame)
 
 # print("======= 获取任务详情 =============")
-# task_info = api.query.task_info(task_ids_list=[13652193])
+# task_info = api.query.task_info(task_ids_list=[1479311])
 # print(task_info)
 #
 # print("======= 添加自定义标签 =============")
-# add_label_name = api.tag.add_label(new_name="test_tag4", status=0)
+# add_label_name = api.tag.add_label(new_name="test_tag42", status=0)
 # print(add_label_name)
 
 # print("======= 删除自定义标签 =============")
-# delete_label_name = api.tag.delete_label(del_name="test_tag5")
+# delete_label_name = api.tag.delete_label(del_name="test_tag4")
 # print(delete_label_name)
 
 # print("======= 获取自定义标签 =============")
@@ -129,9 +129,9 @@ api = RayvisionAPI(access_id=render_para['access_id'],
 #     "cgName": "Maya",
 #     "cgVersion": "2020",
 #     "renderLayerType": 0,
-#     "editName": "testRenderEnv7",
+#     "editName": "testRenderEnv22",
 #     "renderSystem": 1,
-#     "pluginIds": [1166]
+#     "pluginIds": [1166],
 # }
 # add_user_env = api.env.add_render_env(data=env)
 # print(add_user_env)
@@ -143,7 +143,7 @@ api = RayvisionAPI(access_id=render_para['access_id'],
 #     "cgName": "Maya",
 #     "cgVersion": "2020",
 #     "renderLayerType": 0,
-#     "editName": "testRenderEnv3",
+#     "editName": "testRenderEnv20",
 #     "renderSystem": 1,
 #     "pluginIds": [2703],
 # }
@@ -151,29 +151,29 @@ api = RayvisionAPI(access_id=render_para['access_id'],
 # print(update_user_env)
 
 # print("======= 删除用户渲染环境配置 =============")
-# delete_user_env = api.env.delete_render_env(edit_name="testRenderEnv3")
+# delete_user_env = api.env.delete_render_env(edit_name="testRenderEnv21")
 # print(delete_user_env)
 
 # print("======= 设置默认渲染环境配置 =============")
-# set_default_user_env = api.env.set_default_render_env(edit_name="testRenderEnv6")
+# set_default_user_env = api.env.set_default_render_env(edit_name="testRenderEnv7")
 # print(set_default_user_env)
 
 # print("======= 获取用户渲染环境配置 =============")
-# user_render_config = api.env.get_render_env(name='maya')
+# user_render_config = api.env.get_render_env(name='houdini', os_name=0)
 # print(user_render_config)
 
 
 # print("======= 任务进度图 =============")
-# task_processing_img = api.query.get_task_processing_img(task_id=14470635, frame_type=2)
+# task_processing_img = api.query.get_task_processing_img(task_id=1479225)
 # print(task_processing_img)
 
 # print("======= 设置任务超时停止时间 =============")
-# set_task_overtime = api.task.set_task_overtime_top(task_id_list=[13790691], overtime=60)
+# set_task_overtime = api.task.set_task_overtime_top(task_id_list=[1479307], overtime=60)
 # print(set_task_overtime)
 
 
 # print("======= 加载缩略图 =============")
-# frame_thumbnall = api.query.get_frame_thumbnall(frame_id=448872939)
+# frame_thumbnall = api.query.get_frame_thumbnall(frame_id=107729597)
 # print(frame_thumbnall)
 
 # print("======= 获取镭速传输信息 =============")
@@ -186,10 +186,23 @@ api = RayvisionAPI(access_id=render_para['access_id'],
 
 
 # print("======= 全速渲染 =============")
-# full_speed_render = api.task.full_speed(task_id_list=[23750805])
+# full_speed_render = api.task.full_speed(task_id_list=[1479311])
 # print(full_speed_render)
 
 
+# print("======= 获取传输配置 =============")
+# transfer_config = api.transmit.get_transfer_config()
+# print(json.dumps(transfer_config, indent=4, ensure_ascii=False))
+
+# print("======= 添加任务标签 =============")
+# add_task_tag = api.tag.add_task_tag(task_ids=[1479311], tag="dyt_test")
+# print(add_task_tag)
+
+
+# print("======= 删除任务标签 =============")
+# delete_task_tag = api.tag.delete_task_tag(tag_ids=[541, 539])
+# print(delete_task_tag)
+
 # print(end - start)
 
 # if __name__ == '__main__':
