@@ -85,7 +85,7 @@ class QueryOperator(object):
 
     def get_task_list(self, page_num=1, page_size=100, status_list=None,
                       search_keyword=None,
-                      start_time=None, end_time=None):
+                      start_time=None, end_time=None, recycle_flag=None):
         """Get task list.
 
         An old to the new row, the old one.
@@ -97,6 +97,8 @@ class QueryOperator(object):
             search_keyword (string): Optional, scenario name or job ID.
             start_time (string): Optional, search limit for start time.
             end_time (string): Optional, search limit for end time.
+            recycle_flag (int): 1 or 0, 1,Identifies query deleted tasks. When this flag is turned on,
+             other conditional query flags should be turned off, otherwise the current flag will not take effect.
 
         Returns:
             dict: Task info, please see the documentation for details.
@@ -135,6 +137,8 @@ class QueryOperator(object):
             data['startTime'] = start_time
         if end_time:
             data['endTime'] = end_time
+        if recycle_flag:
+            data["recycleFlag"] = recycle_flag
         return self._connect.post(self._connect.url.getTaskList, data)
 
     def task_frames(self, task_id, page_num=1, page_size=100,
